# Developer documentation

## Developer setup
To set up your development environment, you not only need to install the dependencies of the project's code itself but also some modules for testing and keeping the repo clean through pre-commit hooks.

- Clone the repository: `git clone https://gitlab.com/octopus-code/postopus.git` (https) or `git clone git@gitlab.com:octopus-code/postopus.git` (ssh)
- Switch to the directory: `cd postopus`
- Upgrade pip to the newest version: `python3 -m pip install --upgrade pip`
- Create a [virtual environment](https://docs.python.org/3/library/venv.html) (recommended): `python3 -m venv .venv && source .venv/bin/activate`
- Install the sources including development dependencies: `pip install -e '.[dev]'` (or `pip install -e .[dev,docs]` if you want to build the documentation)
- Setup [pre-commit](https://pre-commit.com/): `pre-commit install`


### Testing
Run `pytest` to execute the tests. The data to run the tests is generated by [pytest fixtures](https://docs.pytest.org/en/6.2.x/fixture.html#what-fixtures-are).
They are provided e.g. in [`tests.utils.common_runs`](tests/utils/common_runs.py) and use the input files in [`tests/data/`](tests/data/). Therefore `octopus` must be available in the `PATH`.
Note that `octopus` will not be invoked again if the data for a run already exists and the input files have not changed in the meantime.

### Release

Currently, the following [invoke](https://www.pyinvoke.org/) tasks are available:

- **release**:   Run the release steps, which include syncing the git repo, building the
package and pushing it to PyPI. By default, the task uploads to the test server of PyPI; use the
flag `--test=False` to upload to the main PyPI server. Release to the main PyPI can only
be done from the main branch. Example run:

```bash
$ invoke release --no-test
```

The current commit must be tagged, otherwise the script will exit with a non-zero exit code.
The invoke command does run a `git push` if it sees that the current tag is not
published and it is running in `--no-test`.

Note we highly recommend using the `--debug` flag of `invoke`, specially if something is
not working as expected. By default, invoke fails silently.

See also `invoke --help release`.

## MPCDF Repository syncronization
The MPCDF Binder only works with repositories hostet at
[MPCDF Gitlab](https://gitlab.mpcdf.mpg.de/).
Therefore the main branch is pushed from gitlab.com to the MPCDF Gitlab.
The syncronization should happen automatically every time the main branch changes (within 5 minutes as described in the [Gitlab documentation](https://docs.gitlab.com/ee/user/project/repository/mirror/push.html)).


To achieve this the MPCDF Repository is added in Settings -> Repository -> Mirroring repositories.
This requires an access token which was created with "Developer" Role in the MPCDF Gitlab (Settings -> Access Tokens).
